@@ -231,7 +231,7 @@ def test_cli_with_multiple_env_var_index_url_and_tilde_req():
     expected_file = test_env.get_test_loc("tilde_req-expected-env.json", must_exist=False)
     specifier = "zipp~=3.8.0"
     os.environ["PYINSP_INDEX_URL"] = (
-        "https://pypi.org/simple https://thirdparty.aboutcode.org/pypi/simple/"
+        "https://pypi.org/simple https://thirdparty.aboutcode.org/pypi/simple"
     )
     check_specs_resolution(
         specifier=specifier,
@@ -533,7 +533,7 @@ def test_passing_of_json_pdt_and_json_flags():
 def test_version_option():
     options = ["--version"]
     rc, stdout, stderr = run_cli(options=options)
-    assert "0.14.0" in stdout
+    assert "0.14.3" in stdout
 
 
 def test_passing_of_netrc_file_that_does_not_exist():
